@@ -1,7 +1,6 @@
 import os
 import time
 from dataclasses import dataclass
-from typing import Optional
 
 from dataclasses_jsonschema import JsonSchemaMixin
 
@@ -46,7 +45,7 @@ def wait_for(timeout: float = 10.0) -> None:
 
 
 @handle(SceneServiceException, logger, message="Failed to add or update the collision model.")
-def upsert_collision(model: Models, pose: Pose, mesh_parameters: Optional[MeshParameters] = None) -> None:
+def upsert_collision(model: Models, pose: Pose, mesh_parameters: None | MeshParameters = None) -> None:
     """Adds arbitrary collision model to the collision scene.
 
     :param model: Box, Sphere, Cylinder, Mesh
@@ -71,7 +70,7 @@ def upsert_collision(model: Models, pose: Pose, mesh_parameters: Optional[MeshPa
 
     if model.type() == Model3dType.MESH:
 
-        params["meshFileId"] = params.pop("data_id")
+        params["meshFileId"] = params.pop("asset_id")
 
         if mesh_parameters:
             params.update(mesh_parameters.to_dict())
@@ -111,10 +110,10 @@ def delete_all_collisions() -> None:
 
 
 @handle(SceneServiceException, logger, message="Failed to start the scene.")
-def start() -> None:
+def start(timeout: rest.OptTimeout = None) -> None:
     """To be called after all objects are created."""
 
-    rest.call(rest.Method.PUT, f"{URL}/system/start")
+    rest.call(rest.Method.PUT, f"{URL}/system/start", timeout=timeout)
 
 
 @handle(SceneServiceException, logger, message="Failed to stop the scene.")
