@@ -2,13 +2,13 @@ from __future__ import annotations
 
 import abc
 import copy
-import uuid
 from dataclasses import dataclass, field
 from datetime import datetime
 from enum import Enum, unique
 from json import JSONEncoder
 from typing import Any, Iterator, NamedTuple, Optional, TypeVar, cast
 
+import fastuuid as uuid
 import numpy as np
 import quaternion
 from dataclasses_jsonschema import DEFAULT_SCHEMA_TYPE, JsonSchemaMixin
@@ -355,6 +355,7 @@ class ProjectRobotJoints(JsonSchemaMixin, ModelMixin):
     joints: list[Joint]
     is_valid: bool = False
     arm_id: Optional[str] = None
+    end_effector_id: Optional[str] = None
     id: str = ""
 
     @classmethod
@@ -382,7 +383,6 @@ class SceneObject(JsonSchemaMixin, ModelMixin):
     type: str
     pose: Optional[Pose] = None
     parameters: list[Parameter] = field(default_factory=list)
-    children: list[SceneObject] = field(default_factory=list)
     id: str = ""
 
     @classmethod
@@ -749,19 +749,6 @@ class BroadcastInfo(JsonSchemaMixin):
     port: int
 
 
-@dataclass
-class Asset(JsonSchemaMixin):
-    """Untyped object (JSON)."""
-
-    id: str
-    name: str
-    description: Optional[str] = None
-    uri: Optional[str] = None
-    type: Optional[str] = None
-    tags: Optional[list[str]] = None
-    metadata: Optional[str] = None  # json
-
-
 @dataclass
 class Error(JsonSchemaMixin):
     code: int
