@@ -1,5 +1,5 @@
 import inspect
-from typing import Any, Optional
+from typing import Any
 
 from arcor2.parameter_plugins import ParameterPluginException
 from arcor2.parameter_plugins.base import ParameterPlugin
@@ -24,6 +24,7 @@ def load_plugins() -> None:
     from arcor2.parameter_plugins.integer_enum import IntegerEnumPlugin
     from arcor2.parameter_plugins.joints import JointsPlugin
     from arcor2.parameter_plugins.pose import PosePlugin
+    from arcor2.parameter_plugins.position import PositionPlugin
     from arcor2.parameter_plugins.string import StringPlugin
     from arcor2.parameter_plugins.string_enum import StringEnumPlugin
 
@@ -38,6 +39,7 @@ def load_plugins() -> None:
         IntegerEnumPlugin,
         JointsPlugin,
         PosePlugin,
+        PositionPlugin,
         # PoseListPlugin,
         StringPlugin,
         # StringListPlugin,
@@ -87,7 +89,7 @@ def plugin_from_type(param_type: type[Any]) -> type[ParameterPlugin]:
         except AttributeError:
             type_name = str(param_type)
 
-        plugin: Optional[type[ParameterPlugin]] = None
+        plugin: None | type[ParameterPlugin] = None
         for k, v in non_exact_types().items():
             if inspect.isclass(param_type) and issubclass(param_type, k):
                 if plugin is not None:
