@@ -1,5 +1,3 @@
-from typing import Optional
-
 from arcor2.data.common import ActionMetadata
 from arcor2.object_types.abstract import Generic
 
@@ -8,13 +6,13 @@ class ParamToReturn(Generic):
 
     _ABSTRACT = False
 
-    def bool_param(self, param: bool, *, an: Optional[str] = None) -> bool:
+    def bool_param(self, param: bool, *, an: None | str = None) -> bool:
         return param
 
-    def int_param(self, param: int, *, an: Optional[str] = None) -> int:
+    def int_param(self, param: int, *, an: None | str = None) -> int:
         return param
 
-    def double_param(self, param: float, *, an: Optional[str] = None) -> float:
+    def double_param(self, param: float, *, an: None | str = None) -> float:
         return param
 
     bool_param.__action__ = ActionMetadata()  # type: ignore
